==> nextcloud-24.0.9.tgz: nextcloud/apps/theming/l10n/es.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "El nombre provisto es demasiado largo",
    "The given web address is too long" : "La dirección web es demasiado larga",
    "The given web address is not a valid URL" : "La dirección web indicada no es una URL válida",
    "The given legal notice address is too long" : "El aviso legal dado es demasiado largo",
    "The given legal notice address is not a valid URL" : "La dirección del aviso legal no es una URL válida",
    "The given privacy policy address is too long" : "La dirección de la política de privacidad dada es demasiado larga",
    "The given privacy policy address is not a valid URL" : "La directive de privacidad indicada no es una URL válida",
    "The given slogan is too long" : "El eslogan provisto es demasiado largo",
    "The given color is invalid" : "El color provisto es inválido",
    "Disable-user-theming should be true or false" : "Deshabilitar-tematización-de-usuario debe ser verdadero o falso",
    "Saved" : "Guardado",
    "The file was uploaded" : "Se ha subido el archivo",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo para subir excede la directiva upload_max_filesize en php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo para subir excede la directiva MAX_FILE_SIZE que se especificó en el formulario HTML",
    "The file was only partially uploaded" : "El archivo se ha subido solo parcialmente",
    "No file was uploaded" : "No se ha subido ningún archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No se puede escribir el archivo en el disco",
    "A PHP extension stopped the file upload" : "Una extensión PHP ha cancelado la subida de archivos",
    "No file uploaded" : "No se ha subido archivo",
    "Cleanup old theming cache" : "Borrar el caché antiguo de tematización",
    "Failed to delete folder: \"%1$s\", error: %2$s" : "Fallo al eliminar la carpeta: \"%1$s\", error: %2$s",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ya estás usando un tema personalizado. La configuración de la aplicación de temas puede ser sobrescrita por el.",
    "Theming" : "Tema",
    "Appearance and accessibility" : "Apariencia y accesibilidad",
    "Dark theme with high contrast mode" : "Tema oscuro con modo de alto contraste",
    "Enable dark high contrast mode" : "Activar el modo oscuro de alto contraste",
    "Similar to the high contrast mode, but with dark colours." : "Similar al modo de alto contraste, pero con colores oscuros",
    "Dark theme" : "Tema oscuro",
    "Enable dark theme" : "Activar tema oscuro",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Un tema oscuro para aliviar tu vista, reduciendo la luminosidad y el brillo de la pantalla",
    "System default theme" : "Tema por defecto del sistema",
    "Enable the system default" : "Habilitar el por defecto del sistema",
    "Using the default system appearance." : "Utilizando la apariencia por defecto del sistema",
    "Dyslexia font" : "Tipo de letra para dislexia",
    "Enable dyslexia font" : "Activa tipo de letra para dislexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic es un tipo de letra libre diseñada para reducir algunos de los errores de lectura comunes causados por la dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Activar modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un modo de alto contraste para facilitar la navegación. Se reducirá la calidad visual pero se aumentará la claridad.",
    "Light theme" : "Tema claro",
    "Enable the default light theme" : "Activar el tema claro",
    "The default light appearance." : "La apariencia clara por defecto",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidad",
    "Adjust the Nextcloud theme" : "Ajusta el tema de Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Los temas hacen posible personalizar fácilmente la apariencia de tu instancia y los clientes soportados. Esto será visible para todos los usuarios.",
    "Advanced options" : "Opciones avanzadas",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale la extensión PHP ImageMagick con soporte a imágenes SVG para generar automáticamente favicons basados en el logo cargado y el color.",
    "Name" : "Nombre",
    "Web link" : "Enlace web",
    "a safe home for all your data" : "un hogar seguro para todos tus datos",
    "Slogan" : "Eslogan",
    "Color" : "Color",
    "Logo" : "Logo",
    "Upload new logo" : "Subir nuevo logo",
    "Background and login image" : "Imágen de fondo y de ingreso",
    "Upload new background and login image" : "Cargar una nueva imagen de fondo y de ingreso",
    "Legal notice link" : "Enlace al aviso legal",
    "Privacy policy link" : "Enlace a la política de privacidad",
    "Header logo" : "Logo de la cabecera",
    "Upload new header logo" : "Subir nuevo logo de la cabecera",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Subir nuevo favicon",
    "User settings" : "Configuración de usuario",
    "Disable user theming" : "Deshabilitar tematización de usuario",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Aunque puede seleccionar y personalizar su instancia, los usuarios pueden cambiar su fondo y colores. Si quiere forzar su personalización, puede activar esto.",
    "Keyboard shortcuts" : "Atajos de teclado",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "En algunos casos, los atajos de teclado pueden interferir con las herramientas de accesibilidad. De manera de permitir enfocar correctamente su herramienta, puede deshabilitar todos los atajos de teclado aquí. Esto también deshabilitará todos los atajos disponibles en las aplicaciones.",
    "Disable all keyboard shortcuts" : "Deshabilitar todos los atajos de teclado",
    "Background" : "Imagen de fondo",
    "Customization has been disabled by your administrator" : "La personalización ha sido deshabilitada por el administrador",
    "Set a custom background" : "Establecer un fondo personalizado",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "El acceso universal es muy importante para nosotros. Seguimos los estándares web y verificamos que todo es manejable sin ratón y con software de asistencia, como un lector de pantalla. Nuestro objetivo es cumplir con las {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 en nivel AA y, con el tema de alto contraste, en nivel AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si encuentras cualquier problema, no dudes en informar de ellos en {issuetracker}nuestro tracker de problas{linkend}. Y si quieres involucrarte, ¡puedes unirte a {designteam}nuestro equipo de diseño{linkend}!",
    "Custom background" : "Fondo personalizado",
    "Default background" : "Fondo por defecto",
    "Change color" : "Cambiar color",
    "Remove background" : "Eliminar fondo",
    "Select a background from your files" : "Seleccionar un fondo desde tus archivos",
    "Theme selection is enforced" : "La selección del tema es forzada",
    "Select a custom color" : "Seleccionar un color personalizado",
    "Reset to default" : "Vovler a configuración por defecto",
    "Upload" : "Subir",
    "Remove background image" : "Eliminar imagen de fondo",
    "Loading preview…" : "Cargando previsualización...",
    "Admin" : "Administración",
    "Error uploading the file" : "Error al subir el archivo",
    "Name cannot be empty" : "El nombre no puede estar vacío",
    "Open documentation" : "Abrir la documentación",
    "https://…" : "https://…",
    "Login image" : "Imagen de fondo para el inicio de sesión",
    "Upload new login background" : "Subir una nueva imagen de fondo para inicio de sesión",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instala la extensión de PHP Imagemagick con soporte para imágenes SVG para generar automáticamente faviconos basados en el logo y color subidos.",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "En algunos casos, los atajos de teclado pueden interferir con las herramientas de accesibilidad. De manera de permitir enfocar correctamente tú herramienta, puedes deshabilitar todos los atajos de teclado aquí. Esto también deshabilitará todos los atajos disponibles en las aplicaciones.",
    "Pick from Files" : "Elegir de Archivos",
    "Default image" : "Imagen predeterminada",
    "Custom color" : "Colores personalizados",
    "Plain background" : "Fondo liso",
    "Insert from {productName}" : "Insertar desde {productName}",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Aunque puede seleccionar y personalizar su instancia, los usuarios pueden cambiar su fondo y colores. Si quiere forzar su personalización, puede activar esta casilla."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-24.0.11.tgz: nextcloud/apps/theming/l10n/es.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "El nombre provisto es demasiado largo",
    "The given web address is too long" : "La dirección web es demasiado larga",
    "The given web address is not a valid URL" : "La dirección web indicada no es una URL válida",
    "The given legal notice address is too long" : "El aviso legal dado es demasiado largo",
    "The given legal notice address is not a valid URL" : "La dirección del aviso legal no es una URL válida",
    "The given privacy policy address is too long" : "La dirección de la política de privacidad dada es demasiado larga",
    "The given privacy policy address is not a valid URL" : "La directive de privacidad indicada no es una URL válida",
    "The given slogan is too long" : "El eslogan provisto es demasiado largo",
    "The given color is invalid" : "El color provisto es inválido",
    "Disable-user-theming should be true or false" : "Deshabilitar-tematización-de-usuario debe ser verdadero o falso",
    "Saved" : "Guardado",
    "The file was uploaded" : "Se ha subido el archivo",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo para subir excede la directiva upload_max_filesize en php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo para subir excede la directiva MAX_FILE_SIZE que se especificó en el formulario HTML",
    "The file was only partially uploaded" : "El archivo se ha subido solo parcialmente",
    "No file was uploaded" : "No se ha subido ningún archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No se puede escribir el archivo en el disco",
    "A PHP extension stopped the file upload" : "Una extensión PHP ha cancelado la subida de archivos",
    "No file uploaded" : "No se ha subido archivo",
    "Failed to clean up the old administration theming images folder" : "Fallo al limpiar la carpeta antigua del administrador con las imágenes de temas",
    "Failed to clean up the old administration image folder" : "Fallo al limpiar la carpeta de imágenes de administración antigua",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ya estás usando un tema personalizado. La configuración de la aplicación de temas puede ser sobrescrita por el.",
    "Theming" : "Tema",
    "Appearance and accessibility" : "Apariencia y accesibilidad",
    "Dark theme with high contrast mode" : "Tema oscuro con modo de alto contraste",
    "Enable dark high contrast mode" : "Activar el modo oscuro de alto contraste",
    "Similar to the high contrast mode, but with dark colours." : "Similar al modo de alto contraste, pero con colores oscuros",
    "Dark theme" : "Tema oscuro",
    "Enable dark theme" : "Activar tema oscuro",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Un tema oscuro para aliviar tu vista, reduciendo la luminosidad y el brillo de la pantalla",
    "System default theme" : "Tema por defecto del sistema",
    "Enable the system default" : "Habilitar el por defecto del sistema",
    "Using the default system appearance." : "Utilizando la apariencia por defecto del sistema",
    "Dyslexia font" : "Tipo de letra para dislexia",
    "Enable dyslexia font" : "Activa tipo de letra para dislexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic es un tipo de letra libre diseñada para reducir algunos de los errores de lectura comunes causados por la dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Activar modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un modo de alto contraste para facilitar la navegación. Se reducirá la calidad visual pero se aumentará la claridad.",
    "Light theme" : "Tema claro",
    "Enable the default light theme" : "Activar el tema claro",
    "The default light appearance." : "La apariencia clara por defecto",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidad",
    "Adjust the Nextcloud theme" : "Ajusta el tema de Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Los temas hacen posible personalizar fácilmente la apariencia de tu instancia y los clientes soportados. Esto será visible para todos los usuarios.",
    "Advanced options" : "Opciones avanzadas",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale la extensión PHP ImageMagick con soporte a imágenes SVG para generar automáticamente favicons basados en el logo cargado y el color.",
    "Name" : "Nombre",
    "Web link" : "Enlace web",
    "a safe home for all your data" : "un hogar seguro para todos tus datos",
    "Slogan" : "Eslogan",
    "Color" : "Color",
    "Logo" : "Logo",
    "Upload new logo" : "Subir nuevo logo",
    "Background and login image" : "Imágen de fondo y de ingreso",
    "Upload new background and login image" : "Cargar una nueva imagen de fondo y de ingreso",
    "Legal notice link" : "Enlace al aviso legal",
    "Privacy policy link" : "Enlace a la política de privacidad",
    "Header logo" : "Logo de la cabecera",
    "Upload new header logo" : "Subir nuevo logo de la cabecera",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Subir nuevo favicon",
    "User settings" : "Configuración de usuario",
    "Disable user theming" : "Deshabilitar tematización de usuario",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Aunque puede seleccionar y personalizar su instancia, los usuarios pueden cambiar su fondo y colores. Si quiere forzar su personalización, puede activar esto.",
    "Keyboard shortcuts" : "Atajos de teclado",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "En algunos casos, los atajos de teclado pueden interferir con las herramientas de accesibilidad. De manera de permitir enfocar correctamente su herramienta, puede deshabilitar todos los atajos de teclado aquí. Esto también deshabilitará todos los atajos disponibles en las aplicaciones.",
    "Disable all keyboard shortcuts" : "Deshabilitar todos los atajos de teclado",
    "Background" : "Imagen de fondo",
    "Customization has been disabled by your administrator" : "La personalización ha sido deshabilitada por el administrador",
    "Set a custom background" : "Establecer un fondo personalizado",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "El acceso universal es muy importante para nosotros. Seguimos los estándares web y verificamos que todo es manejable sin ratón y con software de asistencia, como un lector de pantalla. Nuestro objetivo es cumplir con las {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 en nivel AA y, con el tema de alto contraste, en nivel AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si encuentras cualquier problema, no dudes en informar de ellos en {issuetracker}nuestro tracker de problas{linkend}. Y si quieres involucrarte, ¡puedes unirte a {designteam}nuestro equipo de diseño{linkend}!",
    "Custom background" : "Fondo personalizado",
    "Default background" : "Fondo por defecto",
    "Change color" : "Cambiar color",
    "No background" : "Sin imagen de fondo",
    "Select a background from your files" : "Seleccionar un fondo desde tus archivos",
    "Theme selection is enforced" : "La selección del tema es forzada",
    "Select a custom color" : "Seleccionar un color personalizado",
    "Reset to default" : "Vovler a configuración por defecto",
    "Upload" : "Subir",
    "Remove background image" : "Eliminar imagen de fondo",
    "Loading preview…" : "Cargando previsualización...",
    "Admin" : "Administración",
    "Error uploading the file" : "Error al subir el archivo",
    "Name cannot be empty" : "El nombre no puede estar vacío",
    "Open documentation" : "Abrir la documentación",
    "https://…" : "https://…",
    "Login image" : "Imagen de fondo para el inicio de sesión",
    "Upload new login background" : "Subir una nueva imagen de fondo para inicio de sesión",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instala la extensión de PHP Imagemagick con soporte para imágenes SVG para generar automáticamente faviconos basados en el logo y color subidos.",
    "Migrate and clean up admin theming images" : "Migrar y limpiar las imágenes de temas antiguos del administrador",
    "Failed to clean up the old admin theming images folder" : "Fallo al limpiar la carpeta antigua del administrador con las imágenes de temas",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "En algunos casos, los atajos de teclado pueden interferir con las herramientas de accesibilidad. De manera de permitir enfocar correctamente tú herramienta, puedes deshabilitar todos los atajos de teclado aquí. Esto también deshabilitará todos los atajos disponibles en las aplicaciones.",
    "Pick from Files" : "Elegir de Archivos",
    "Default image" : "Imagen predeterminada",
    "Custom color" : "Colores personalizados",
    "Plain background" : "Fondo liso",
    "Insert from {productName}" : "Insertar desde {productName}",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Aunque puede seleccionar y personalizar su instancia, los usuarios pueden cambiar su fondo y colores. Si quiere forzar su personalización, puede activar esta casilla."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
